resource "triton_machine" "nextcloud-web" {
  name     = "nextcloud-web"
  package  = "storage-medium"
  image    = data.triton_image.alpine.id
  networks = [
    data.triton_network.private.id,
    data.triton_network.public.id
  ]
  # rules are defined in firewall.tf
  firewall_enabled = true

  user_script = file("${path.module}/scripts/install-ansible.sh")

  affinity = ["role==nc-db"]

  # this creates the internal+external DNS records
  # nc-web.svc.e5756d08-36fd-424b-f8bc-acdb92ca7b82.lev-1.int.greenbaum.zone
  # nc-web.svc.e5756d08-36fd-424b-f8bc-acdb92ca7b82.lev-1.greenbaum.zone
  cns {
    services = ["nc-web"]
  }

  # these tags will be used mainly for firewall rules
  tags = {
    ansible-nc = true
    project = "nextcloud"
    role    = "nc-web"
  }
}

resource "triton_machine" "nextcloud-db" {
  name     = "nextcloud-db"
  package  = "sample-2G"
  image    = data.triton_image.alpine.id
  networks = [data.triton_network.private.id]
  # rules are defined in firewall.tf
  firewall_enabled            = true
  deletion_protection_enabled = true

  user_script = file("${path.module}/scripts/install-ansible.sh")

  # this creates the internal DNS record
  # nc-db.svc.e5756d08-36fd-424b-f8bc-acdb92ca7b82.lev-1.int.greenbaum.zone
  cns {
    services = ["nc-db"]
  }

  # these tags will be used mainly for firewall rules
  tags = {
    ansible-nc = true
    project = "nextcloud"
    role    = "nc-db"
    "tritoncli.ssh.proxy" = "nextcloud-web"
  }
}
