#!/bin/sh

set -e

# exit early if we already ran this
if [ -f /opt/.ansible-installed ]; then
  exit 0
fi

apk update
apk upgrade

apk add ansible

echo
echo "   Alpine Linux ready for nextcloud."
echo
ansible --version

# Allow SSH TCP forwarding for ProxyJump
sed -i 's/^\AllowTcpForwarding\ no/AllowTcpForwarding yes/' /etc/ssh/sshd_config

# SSH hardening
# https://www.ssh-audit.com/hardening_guides.html

# Re-generate the RSA and ED25519 host keys
rm /etc/ssh/ssh_host_*
ssh-keygen -t rsa -b 4096 -f /etc/ssh/ssh_host_rsa_key -N ""
ssh-keygen -t ed25519 -f /etc/ssh/ssh_host_ed25519_key -N ""
# Enable the RSA and ED25519 host keys
sed -i 's/^\#HostKey \/etc\/ssh\/ssh_host_\(rsa\|ed25519\)_key$/HostKey \/etc\/ssh\/ssh_host_\1_key/g' /etc/ssh/sshd_config
# Remove small Diffie-Hellman moduli
awk '$5 >= 3071' /etc/ssh/moduli > /etc/ssh/moduli.safe
mv -f /etc/ssh/moduli.safe /etc/ssh/moduli
# Restrict supported key exchange, cipher, and MAC algorithms
printf "\n# Restrict key exchange, cipher, and MAC algorithms, as per sshaudit.com\n# hardening guide.\nKexAlgorithms curve25519-sha256,curve25519-sha256@libssh.org,diffie-hellman-group16-sha512,diffie-hellman-group18-sha512,diffie-hellman-group-exchange-sha256\nCiphers chacha20-poly1305@openssh.com,aes256-gcm@openssh.com,aes128-gcm@openssh.com,aes256-ctr,aes192-ctr,aes128-ctr\nMACs hmac-sha2-256-etm@openssh.com,hmac-sha2-512-etm@openssh.com,umac-128-etm@openssh.com\nHostKeyAlgorithms ssh-ed25519,ssh-ed25519-cert-v01@openssh.com" >> /etc/ssh/sshd_config
# Restart OpenSSH server
rc-service sshd restart

# take note that we ran this
touch /opt/.ansible-installed
